# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.96) ? 1 : 0);' 2>/dev/null || echo 0)

# CPAN::Meta isn't available in EPEL < 7 due to requirement of perl(version) ≥ 0.88
%global cpan_meta_available %(expr 0%{?fedora} + 0%{?rhel} '>' 6)

# TODO: BR: perl(Test::Code::TidyAll) >= 0.24 when available
# NOTE: BR: perl(Test::Pod::No404s) not included as it requires network access

Name:		perl-Package-DeprecationManager
Version:	0.14
Release:	4%{?dist}
Summary:	Manage deprecation warnings for your distribution
Group:		Development/Libraries
License:	Artistic 2.0
URL:		http://search.cpan.org/dist/Package-DeprecationManager/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DR/DROLSKY/Package-DeprecationManager-%{version}.tar.gz
Patch0:		Package-DeprecationManager-0.14-no-Test::Code::TidyAll.patch
Patch1:		Package-DeprecationManager-0.14-old-List::Util.patch
Patch2:		Package-DeprecationManager-0.14-old-Test::More.patch
Patch3:		Package-DeprecationManager-0.14-stopwords.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	perl
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
%if 0%{?fedora} < 21 || 0%{?rhel} < 8
BuildRequires:	perl(List::MoreUtils)
%else
BuildRequires:	perl(List::Util)
%endif
BuildRequires:	perl(Params::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(Sub::Install)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Requires)
# Optional Tests
%if %{cpan_meta_available}
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
%endif
%if 0%{?fedora} || 0%{?rhel} > 6
BuildRequires:	perl(Test::Output) >= 0.16
%endif
%if 0%{!?perl_bootstrap:1} && ! 0%{?rhel}
# Author Tests
BuildRequires:	perl(Pod::Wordlist)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Spelling), hunspell-en
# Release Tests
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Test::CPAN::Changes) >= 0.19
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Pod::LinkCheck)
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Version) >= 1.002
%endif
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
This module allows you to manage a set of deprecations for one or more modules.

When you import Package::DeprecationManager, you must provide a set of
-deprecations as a hash ref. The keys are "feature" names, and the values are
the version when that feature was deprecated.

%prep
%setup -q -n Package-DeprecationManager-%{version}

# Test::Code::TidyAll not yet available in Fedora
%patch0

# We need to patch the module if we have an old version of List::Util
%if 0%{?fedora} < 21 || 0%{?rhel} < 8
%patch1
%endif

# Fix tests for Test::More prior to 0.96
%if %{old_test_more}
%patch2
%endif

# "PayPal" not a common dictionary word
%patch3

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
%{_fixperms} %{buildroot}

%check
%if 0%{!?perl_bootstrap:1} && ! 0%{?rhel}
make test AUTHOR_TESTING=1 RELEASE_TESTING=1
%else
make test
%endif

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README.md
%{perl_vendorlib}/Package/
%{_mandir}/man3/Package::DeprecationManager.3*

%changelog
* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.14-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Jun 10 2015 Jitka Plesnikova <jplesnik@redhat.com> - 0.14-3
- Perl 5.22 re-rebuild of bootstrapped packages

* Sat Jun 06 2015 Jitka Plesnikova <jplesnik@redhat.com> - 0.14-2
- Perl 5.22 rebuild

* Tue Apr 21 2015 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14
  - Use any() from List::Util 1.33+ instead of List::MoreUtils
- Add patch to use List::MoreUtils::any() on old distributions where we don't
  have List::Util 1.33+
- Add patch to support building without Test::Code::TidyAll
- Classify buildreqs by usage
- Update patches as needed
- Use %%license where possible
- Don't try to do the author or release tests for RHEL builds

* Fri Aug 29 2014 Jitka Plesnikova <jplesnik@redhat.com> - 0.13-11
- Perl 5.20 rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jul 26 2013 Petr Pisar <ppisar@redhat.com> - 0.13-8
- Perl 5.18 rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jun 19 2012 Petr Pisar <ppisar@redhat.com> - 0.13-5
- Perl 5.16 rebuild

* Thu Jun  7 2012 Paul Howarth <paul@city-fan.org> - 0.13-4
- Add commentary regarding conditionalized buildreqs

* Thu Jun  7 2012 Marcela Mašláňová <mmaslano@redhat.com> - 0.13-3
- Conditionalize aspell-en

* Mon Apr 23 2012 Paul Howarth <paul@city-fan.org> - 0.13-2
- Upstream has dropped Kwalitee test, so drop BR: perl(Test::Kwalitee)

* Fri Mar  9 2012 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13:
  - Fix dist.ini to not add Test::Spelling as a requirement
- Drop %%defattr, redundant since rpm 4.4
- Test::Requires available on all supported distributions

* Mon Mar  5 2012 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12:
  - Fix tests to pass with Carp 1.25 (CPAN RT#75520)
- BR: perl(Test::Spelling), aspell-en
- Add patch to accept "deprecations" as a valid dictionary word
- Update patches to apply cleanly
- Don't need to remove empty directories from buildroot
- Don't use macros for commands
- Drop EPEL-4 support:
  - Drop patch supporting build with ExtUtils::MakeMaker < 6.30

* Thu Jan 12 2012 Paul Howarth <paul@city-fan.org> - 0.11-3
- Fedora 17 mass rebuild

* Tue Jul 19 2011 Petr Sabata <contyk@redhat.com> - 0.11-2
- Perl mass rebuild

* Mon Jun 20 2011 Paul Howarth <paul@city-fan.org> - 0.11-1
- Update to 0.11:
  - Allow an empty hash for the -deprecations parameter
- BR: perl(ExtUtils::MakeMaker)
- BR: perl(Test::CPAN::Changes)
- BR: perl(Pod::Coverage::TrustPod) unconditionally
- Update patches for old ExtUtils::MakeMaker and Test::More compatibility

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 08 2011 Paul Howarth <paul@city-fan.org> - 0.10-2
- Update patches for old Test::More and no Test::Requires
- perl(Pod::Coverage::TrustPod) now available everywhere except EPEL-4

* Sat Jan 08 2011 Iain Arnell <iarnell@gmail.com> - 0.10-1
- Update to 0.10:
  - Test suite uses Test::Fatal instead of Test::Exception

* Mon Oct 18 2010 Paul Howarth <paul@city-fan.org> - 0.09-1
- Update to 0.09:
  - Added a compilation test

* Fri Oct 15 2010 Paul Howarth <paul@city-fan.org> - 0.08-1
- Update to 0.08:
  - The use of regular expressions in ignores didn't really work in 0.06
  - Added missing deps on List::MoreUtils and Test::Requires
  - Replaced Test::Warn with Test::Output in the tests
  - Made the tests actually test what they should be testing
- BR: Test::Output rather than Test::Warn
- Update patches

* Fri Oct 15 2010 Paul Howarth <paul@city-fan.org> - 0.06-1
- Update to 0.06:
  - Removed hard dep on Test::Warn for the benefit of Moose
  - Fixed what looked like a bug in -ignore handling
  - The -ignore parameter now accepts regexes as well as package names
- Update compatibility patches
- BR: List::MoreUtils
- BR: Test::Requires where possible, patch it out elsewhere

* Tue Jul 27 2010 Paul Howarth <paul@city-fan.org> - 0.04-2
- Clean up for Fedora submission

* Mon Jul 26 2010 Paul Howarth <paul@city-fan.org> - 0.04-1
- Initial RPM version
